@@ -6,7 +6,10 @@ import webob
 class Response(webob.Response):
 
     def _get__doc(self):
-        return PyQuery(self.body, parser='html')
+        body = self.body.strip()
+        if body and '<?xml version=' not in body:
+            body = '<?xml version="1.0" encoding="utf-8"?>' + body
+        return PyQuery(body, parser='html')
 
     def _set__doc(self, value):
         self.body = tostring(value[0])
